@@ -1,7 +1,7 @@
 package Struct::Match;
-use 5.006; use strict; use warnings; no warnings qw(void); use utf8; our $VERSION = '0.02';
+use 5.006; use strict; use warnings; no warnings qw(void); use utf8; our $VERSION = '0.03';
 use Combine::Keys qw/combine_keys/; use base 'Import::Export';
-our %STRUCT; our %EX = ('match' => ['all']); 
+our %STRUCT; our %EX = ('match' => ['all'], '%STRUCT' => ['struct', 'all']); 
 BEGIN {
 	%STRUCT = (
 		SCALAR => sub {my $q = quotemeta($_[1]); $_[0] =~ m±^($q)$±;},
@@ -24,7 +24,7 @@ Struct::Match - Exact Match (SCALAR|HASH|ARRAY)'s.
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -32,7 +32,7 @@ Version 0.02
 
 	use Struct::Match qw/match/;
 
-    my $bool = match $airport, $code; # 1
+	my $bool = match $airport, $code; # 1
 
 =cut
 
